@@ -8,7 +8,6 @@ This is the composing game.
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <clutter/clutter.h>
-#include <clutter-gtk/gtk-clutter-embed.h>
 
 
 #include "jammo-texture.h"
@@ -62,9 +61,10 @@ void gui_visualize_playing(void) {
   printf ("composing_game: Duration: %" GST_TIME_FORMAT " .one beat: %" GST_TIME_FORMAT "\n",
   GST_TIME_ARGS (length_of_song), GST_TIME_ARGS (length_of_beat));
 
-//printf("composing_game: start_star timeline\n");
+  //printf("composing_game: start_star timeline\n");
+  int length_ms=(int)(length_of_song/1000000);
+  ClutterTimeline *timeline = clutter_timeline_new (length_ms);
 
-  ClutterTimeline *timeline = clutter_timeline_new_for_duration (length_of_song);
   clutter_timeline_set_loop(timeline, FALSE); 
   g_signal_connect (timeline, "marker-reached", G_CALLBACK (on_timeline_marker_reached),timeline_star_actor);
   g_signal_connect (timeline, "completed", G_CALLBACK (on_timeline_completed),timeline_star_actor);
